#
# spec file for package glfw
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover  3
%if 0%{?is_opensuse}
%bcond_without geany
%else
%bcond_with geany
%endif
Name:           glfw
Version:        3.2.1
Release:        lp150.1.25
Summary:        Framework for OpenGL application development
License:        Zlib
Group:          Development/Libraries/C and C++
Url:            http://www.glfw.org/
Source:         https://github.com/glfw/glfw/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8.12
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
%if 0%{?suse_version} > 1320
BuildRequires:  vulkan-devel
%endif
%if %{with geany}
BuildRequires:  geany
%endif

%description
GLFW is a framework for OpenGL application development. It is a
single library providing a powerful, portable API for otherwise
operating system specific tasks such as opening an OpenGL window, and
reading keyboard, time, mouse and joystick input.

%package -n libglfw%{sover}
Summary:        Framework for OpenGL application development
Group:          System/Libraries

%description -n libglfw%{sover}
GLFW is a framework for OpenGL application development. It is a
single library providing a powerful, portable API for otherwise
operating system specific tasks such as opening an OpenGL window, and
reading keyboard, time, mouse and joystick input.

%package -n libglfw-devel
Summary:        Development files for GLFW, an OpenGL application framework
Group:          Development/Libraries/C and C++
Requires:       cmake
Requires:       libglfw%{sover} = %{version}

%description -n libglfw-devel
GLFW is a framework for OpenGL application development. It is a
single library providing a powerful, portable API for otherwise
operating system specific tasks such as opening an OpenGL window, and
reading keyboard, time, mouse and joystick input.

%prep
%setup -q
find . -type f | xargs sed -i 's/\r//'

# temp geany config directory for allow geany to generate tags
mkdir -p geany_config

%build
# generate geany tags
%if %{with geany}
geany -c geany_config -g glfw.c.tags $(find src \( ! -name CMakeFiles \) -type f \( -iname "*.c" -o -iname "*.h" \) \( ! -iname "win32*" \) \( ! -iname "cocoa*" \)
) include/GLFW/glfw3.h
%endif

%cmake
make %{?_smp_mflags} all

%install
%cmake_install

# install geany tags
%if %{with geany}
install -d %{buildroot}/%{_datadir}/geany/tags/
install -m0644 glfw.c.tags %{buildroot}/%{_datadir}/geany/tags/
%endif

%post   -n libglfw%{sover} -p /sbin/ldconfig
%postun -n libglfw%{sover} -p /sbin/ldconfig

%files -n libglfw%{sover}
%defattr(-,root,root)
%doc COPYING.txt README.md
%{_libdir}/libglfw.so.%{sover}*

%files -n libglfw-devel
%defattr(-,root,root)
%doc examples/*.c
%{_includedir}/GLFW/
%{_libdir}/cmake/glfw3
%{_libdir}/libglfw.so
%{_libdir}/pkgconfig/glfw3.pc
%if %{with geany}
%{_datadir}/geany/
%endif

%changelog
* Sun Feb 12 2017 mpluskal@suse.com
- Update to version 3.2.1:
  * Added on-demand loading of Vulkan and context creation API
    libraries
  * Added _GLFW_VULKAN_STATIC build macro to make the library use
    the Vulkan loader linked statically into the application (#820)
  * Bugfix: Single compilation unit builds failed due to naming
    conflicts (#783)
  * Bugfix: The range checks for glfwSetCursorPos used the wrong
    minimum (#773)
  * Bugfix: Defining GLFW_INCLUDE_VULKAN when compiling the library
    did not fail with the expected error message (#823)
  * Bugfix: Inherited value of CMAKE_MODULE_PATH was clobbered
    (#822)
  * [X11] Bugfix: Window size limits were ignored if the minimum or
    maximum size was set to GLFW_DONT_CARE (#805)
  * [X11] Bugfix: Input focus was set before window was visible,
    causing BadMatch on some non-reparenting WMs (#789,#798)
  * [X11] Bugfix: glfwGetWindowPos and glfwSetWindowPos operated on
    the window frame instead of the client area (#800)
  * [WGL] Added reporting of errors from WGL_ARB_create_context
    extension
  * [GLX] Bugfix: Dynamically loaded entry points were not verified
  * [EGL] Added lib prefix matching between EGL and OpenGL ES
    library binaries
  * [EGL] Bugfix: Dynamically loaded entry points were not verified
- Enable vulkan on Tumbleweed
* Thu Aug 11 2016 rpm@fthiessen.de
- Update to new upstream release 3.2
* Sun Jul 17 2016 jengelh@inai.de
- Trim irrelevant parts from %%description
* Wed May 18 2016 rpm@fthiessen.de
- Made build of geany-tags optional (fix SLE).
* Sat Oct 24 2015 mimi.vx@gmail.com
- Update to version 3.1.2
  * bugfix release, full changelog on http://www.glfw.org/changelog.html
* Thu Sep 17 2015 jengelh@inai.de
- Update to new upstream release 3.1.1
  * This release adds fixes for a number of bugs that together affect
  all supported platforms, most notably workarounds for bugs in
  some popular window managers.
- Reduce overly explicit filelist
* Tue Feb  3 2015 zaitor@opensuse.org
- Update to version 3.1:
  + Added GLFWcursor custom system cursor handle
  + Added glfwCreateCursor, glfwCreateStandardCursor, glfwDestroyCursor and glfwSetCursor for managing system cursor images
  + Added GLFWimage struct for passing 32-bit RGBA images
  + Added monitor and adapter identifier access to native API
  + Added glfwSetDropCallback and GLFWdropfun for receiving dropped files
  + Added glfwPostEmptyEvent for allowing secondary threads to cause glfwWaitEvents to return
  + Added empty test program for verifying posting of empty events
  + Added glfwSetCharModsCallback for receiving character events with modifiers
  + Added glfwGetWindowFrameSize for retrieving the size of the frame around the client area of a window
  + Added GLFW_AUTO_ICONIFY for controlling whether full screen windows automatically iconify (and restore the previous video mode) on focus loss
  + Added GLFW_DONT_CARE for indicating that any value is acceptable
  + Added GLFW_DOUBLEBUFFER for controlling whether to use double buffering
  + Added GLFW_CONTEXT_RELEASE_BEHAVIOR and values GLFW_ANY_RELEASE_BEHAVIOR, GLFW_RELEASE_BEHAVIOR_FLUSH and GLFW_RELEASE_BEHAVIOR_NONE for GL_KHR_context_flush_control support
  + Added GLFW_INCLUDE_ES31 for including the OpenGL ES 3.1 header
  + Added GLFW_FLOATING for creating always-on-top windowed mode windows
  + Added GLFW_FOCUSED window hint for controlling initial input focus
  + Added partial and experimental support for Wayland
  + Added partial and experimental support for Mir
  + Changed the window state attributes (focused, iconified and visible) to query the system directly
  + Changed the default of GLFW_REFRESH_RATE to GLFW_DONT_CARE to maintain the default behavior
  + Changed static library to build as position independent code for easier use from the Rust language
  + Changed glfwGetCursorPos to query the system directly for all cursor modes except captured mode
  + Bugfix: The debug context attribute was set from GL_ARB_debug_output even when a debug context had not been requested
  + Bugfix: The particles example was not linked against the threading library
  + Bugfix: The cursor was not positioned over newly created full screen windows
  + Bugfix: The queried cursor position was not always up-to-date
  + Bugfix: glfwExtensionSupported always failed for OpenGL ES 3.0 and later if the library was compiled for OpenGL ES
  + [X11] Added run-time support for systems lacking the XKB extension
  + [X11] Made GLX 1.3 the minimum supported version
  + [X11] Replaced XRRGetScreenResources with XRRGetScreenResourcesCurrent for monitor property retrieval
  + [X11] Bugfix: The case of finding no usable CRTCs was not detected
  + [X11] Bugfix: Detection of broken Nvidia RandR gamma support did not verify that at least one CRTC was present
  + [X11] Bugfix: A stale _NET_SUPPORTING_WM_CHECK root window property would cause an uncaught BadWindow error
  + [X11] Bugfix: No check was made for the presence of GLX 1.3 when GLX_SGIX_fbconfig was unavailable
  + [X11] Bugfix: The message type of ICCCM protocol events was not checked
  + [X11] Bugfix: glfwDestroyWindow did not flush the output buffer
  + [X11] Bugfix: Window frame interactions were reported as focus events
  + [X11] Bugfix: Workaround for legacy Compiz caused flickering during resize
  + [X11] Bugfix: The name pointer of joysticks were not cleared on disconnection
  + [X11] Bugfix: Video mode resolutions and monitor physical sizes were not corrected for rotated CRTCs
  + [X11] Bugfix: Unicode character input ignored dead keys
  + [X11] Bugfix: X-axis scroll offsets were inverted
  + [X11] Bugfix: Full screen override redirect windows were not always positioned over the specified monitor
  + [X11] Bugfix: Character input did not work for the default "C" locale
  + [X11] Bugfix: Joysticks connected after glfwInit were not detected (temporary inotify solution until proper libudev solution)
- Add pkgconfig(xinerama), pkgconfig(xcursor) BuildRequires: New dependencies.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 3.0.4
  +Added the GLFW_BUILD_DOCS CMake option for controlling whether
  the documentation is built
  +Added the _GLFW_USE_CONFIG_H configuration macro for controlling
  whether to include the configuration header
  +Moved version number macro to internal.h for easier manual compilation
  +Renamed configuration header to glfw_config.h to avoid conflicts
  +Bugfix: The glfw3.pc file did not respect the LIB_SUFFIX CMake option
  +Bugfix: The joysticks test would segfault if a controller had no axes
  +[Win32] Allowed swap interval to be explicitly set to zero on DWM systems
  +[Win32] Bugfix: Removed joystick axis value negation left over from GLFW 2
  +[Win32] Bugfix: Restoring windows using the Win+D hot key did not
  trigger the focus callback
  +[Win32] Bugfix: The disabled cursor mode clip rectangle was updated
  for unfocused windows
  +[Win32] Bugfix: Cursor was not properly re-centered over odd-sized windows
  +[Win32] Bugfix: Negative window positions were reported incorrectly
  +[Win32] Bugfix: The iconify callback was not triggered when switching
  away from a full screen window using Alt+Tab
  +[Win32] Bugfix: Resizing a window with glfwSetWindowSize gave it focus
  +[Cocoa] Added dependency on CoreVideo framework for refresh rate retrieval
  +[Cocoa] Enabled Lion full screen for resizable windowed mode windows
  +[Cocoa] Moved to Cocoa API for application transformation and activation
  +[Cocoa] Bugfix: The GLFW_KEY_GRAVE_ACCENT key was reported as
  GLFW_KEY_WORLD_1 and vice versa
  +[Cocoa] Bugfix: The GLFW_KEY_F13 key was reported as GLFW_KEY_PRINT_SCREEN
  +[Cocoa] Bugfix: Implicit conversion from NSUInteger to int caused
  warnings with Xcode 5
  +[Cocoa] Bugfix: Use of undeclared selectors with @selector caused
  warnings with Xcode 5
  +[Cocoa] Bugfix: The cursor remained visible if moved onto client
  area after having been set to hidden outside it
  +[Cocoa] Bugfix: The refresh rate was zero for all modes of certain monitors
  +[Cocoa] Bugfix: The install_name field of the dynamic library was not set
  +[Cocoa] Bugfix: Full screen windows were never reported as having focus
  +[Cocoa] Bugfix: A superfluous I/O flag test prevented video modes from
  being listed for Thunderbolt monitor
  +[Cocoa] Bugfix: Retrieving the name of some external displays caused segfault
  +[Cocoa] Bugfix: The 10.9 SDK defines GLintptrARB and GLsizeiptrARB
  differently from the Khronos glext.h
  +[Cocoa] Bugfix: Creating hidden windows would steal application focus
  +[Cocoa] Bugfix: Controllers were reported as having zero buttons and axes
  +[Cocoa] Bugfix: Removed joystick axis value negation left over from GLFW 2
  +[X11] Added setting of the WM_CLASS property to the initial window title
  +[X11] Added support for _NET_WM_BYPASS_COMPOSITOR
  +[X11] Bugfix: Removed joystick axis value negation left over from GLFW 2
  +[X11] Bugfix: The position of hidden windows was ignored by Metacity and Compiz
  +[X11] Bugfix: The pthread.h header was not included by the GLX platform header.
- Add upstream new dependencies: cmake, gcc-c++, doxygen, geany,
  pkgconfig(xi)
- Add a dependency to cmake in devel subpackage
- Build the geany tags
- Package README.md into doc directory
- Package examples code in devel subpackage
- Remove the static devel subpackage; not provided anymore
- Fix the home page Url
- Bump so version to 3
* Tue Oct  8 2013 lnussel@suse.de
- install COPYING.txt as well
* Tue Sep 25 2012 adam@mizerski.pl
- update to 2.7.6
- spec improvement and cleanup
  - updated license information
  - changed "BuildRequires: package-name" into
    "BuildRequires: pkgconfig(name)" (fixes Factory build)
- dropped glfw-force_sysctl_support.patch
- dropped glfw-rpmlintrc - there was nothing useful
* Sat Mar 24 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant spec sections
* Mon Nov  7 2011 pascal.bleser@opensuse.org
- update to 2.7.2
- package shlib too
- shared library naming policy
- static lib moved to libglfw-devel-static
* Thu Jun 14 2007 prusnak@suse.cz
- initial version (2.5.0)
